==> ceph_12.2.13.orig.tar.xz: ceph-12.2.13/src/boost/libs/wave/tool/cpp.hpp <==
/*=============================================================================
    Boost.Wave: A Standard compliant C++ preprocessor library

    http://www.boost.org/

    Copyright (c) 2001-2012 Hartmut Kaiser. Distributed under the Boost
    Software License, Version 1.0. (See accompanying file
    LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
=============================================================================*/

#if !defined(CPP_HPP_920D0370_741F_44AF_BF86_F6104BDACF75_INCLUDED)
#define CPP_HPP_920D0370_741F_44AF_BF86_F6104BDACF75_INCLUDED

///////////////////////////////////////////////////////////////////////////////
//  This file may be used as a precompiled header (if applicable)

///////////////////////////////////////////////////////////////////////////////
//  include often used files from the stdlib
#include <iostream>
#include <fstream>
#include <string>
#include <vector>
#include <algorithm>
#include <iterator>

///////////////////////////////////////////////////////////////////////////////
//  include boost config
#include <boost/config.hpp>     //  global configuration information

///////////////////////////////////////////////////////////////////////////////
//  build version
#include "cpp_version.hpp"

///////////////////////////////////////////////////////////////////////////////
//  configure this app here (global configuration constants)
#include "cpp_config.hpp"

///////////////////////////////////////////////////////////////////////////////
//  include required boost libraries
#include <boost/assert.hpp>
#include <boost/pool/pool_alloc.hpp>

#endif // !defined(CPP_HPP_920D0370_741F_44AF_BF86_F6104BDACF75_INCLUDED)

==> ceph_17.2.7.orig.tar.xz: ceph-17.2.7/src/boost/libs/wave/tool/cpp.hpp <==
/*=============================================================================
    Boost.Wave: A Standard compliant C++ preprocessor library

    http://www.boost.org/

    Copyright (c) 2001-2012 Hartmut Kaiser. Distributed under the Boost
    Software License, Version 1.0. (See accompanying file
    LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
=============================================================================*/

#if !defined(BOOST_CPP_HPP_920D0370_741F_44AF_BF86_F6104BDACF75_INCLUDED)
#define BOOST_CPP_HPP_920D0370_741F_44AF_BF86_F6104BDACF75_INCLUDED

///////////////////////////////////////////////////////////////////////////////
//  This file may be used as a precompiled header (if applicable)

///////////////////////////////////////////////////////////////////////////////
//  include often used files from the stdlib
#include <iosfwd>
#include <string>
#include <vector>
#include <algorithm>
#include <iterator>

///////////////////////////////////////////////////////////////////////////////
//  include boost config
#include <boost/config.hpp>     //  global configuration information

///////////////////////////////////////////////////////////////////////////////
//  build version
#include "cpp_version.hpp"

///////////////////////////////////////////////////////////////////////////////
//  configure this app here (global configuration constants)
#include "cpp_config.hpp"

///////////////////////////////////////////////////////////////////////////////
//  include required boost libraries
#include <boost/assert.hpp>
#include <boost/pool/pool_alloc.hpp>

#endif // !defined(BOOST_CPP_HPP_920D0370_741F_44AF_BF86_F6104BDACF75_INCLUDED)
